@@ -235,7 +235,7 @@ class UnshardedSkeletonMergeTask(RegisteredTask):
     skeletons = []
     for segid, frags in skels.items():
       skeleton = self.fuse_skeletons(frags)
-      if self.max_cable_length is None or skel.cable_length() <= self.max_cable_length:
+      if self.max_cable_length is None or skeleton.cable_length() <= self.max_cable_length:
         skeleton = kimimaro.postprocess(
           skeleton, self.dust_threshold, self.tick_threshold
         )
@@ -255,13 +255,13 @@ class UnshardedSkeletonMergeTask(RegisteredTask):
     return [ _ for _ in cf.list(prefix=prefix) ]
 
   def get_skeletons_by_segid(self, filenames):
-    cf = CloudFiles(self.cloudpath, progress=True)
+    cf = CloudFiles(self.cloudpath, progress=False)
     skels = cf.get(filenames)
 
     skeletons = defaultdict(list)
     for skel in skels:
       try:
-        segid = filename_to_segid(skel['filename'])
+        segid = filename_to_segid(skel['path'])
       except ValueError:
         # Typically this is due to preexisting fully
         # formed skeletons e.g. skeletons_mip_3/1588494
@@ -269,7 +269,7 @@ class UnshardedSkeletonMergeTask(RegisteredTask):
 
       skeletons[segid].append( 
         (
-          Bbox.from_filename(skel['filename']),
+          Bbox.from_filename(skel['path']),
           pickle.loads(skel['content'])
         )
       )
@@ -313,11 +313,11 @@ class ShardedSkeletonMergeTask(RegisteredTask):
   def __init__(
     self, cloudpath, shard_no, 
     dust_threshold=4000, tick_threshold=6000,
-    sqlite_db=None, max_cable_length=None
+    spatial_index_db=None, max_cable_length=None
   ):
     super(ShardedSkeletonMergeTask, self).__init__(
       cloudpath, shard_no,  
-      dust_threshold, tick_threshold, sqlite_db,
+      dust_threshold, tick_threshold, spatial_index_db,
       max_cable_length
     )
     self.progress = False
@@ -326,7 +326,11 @@ class ShardedSkeletonMergeTask(RegisteredTask):
   def execute(self):
     # cache is necessary for local computation, but on GCE download is very fast
     # so cache isn't necessary.
-    cv = CloudVolume(self.cloudpath, cache=False, progress=self.progress)
+    cv = CloudVolume(
+      self.cloudpath, 
+      progress=self.progress,
+      spatial_index_db=self.spatial_index_db
+    )
 
     # This looks messy because we are trying to avoid retaining
     # unnecessary memory. In the original iteration, this was 
@@ -432,8 +436,6 @@ class ShardedSkeletonMergeTask(RegisteredTask):
 
   def locations_for_labels(self, labels, cv):
     SPATIAL_EXT = re.compile(r'\.spatial$')
-    if self.sqlite_db:
-      cv.skeleton.spatial_index.sqlite_db = self.sqlite_db
     index_filenames = cv.skeleton.spatial_index.file_locations_per_label(labels)
     for label, locations in index_filenames.items():
       for i, location in enumerate(locations):
@@ -524,4 +526,4 @@ def TransferSkeletonFilesTask(
   cf_src = CloudFiles(cv_src.mesh.meta.layerpath)
   cf_dest = CloudFiles(cv_dest.mesh.meta.layerpath)
 
-  cf_src.transfer_to(cf_dest, paths=cf_src.list(prefix=prefix))
\ No newline at end of file
+  cf_src.transfer_to(cf_dest, paths=cf_src.list(prefix=prefix))
